@@ -335,8 +335,11 @@ class Swagger2Case():
                         def_key = tmp["items"]["originalRef"]
                         para_dict[name] = [self.deal_para_from_def(def_key)]
                     else:
-                        para_dict[name] = [type_value.setdefault(
-                            tmp["items"]["type"], tmp["items"]["type"])]
+                        try:
+                            para_dict[name] = [type_value.setdefault(
+                                tmp["items"]["type"], tmp["items"]["type"])]
+                        except Exception as err:
+                            print(f"出异常了，相关变量：tmp['items']={tmp['items']},详细信息：{err}")
             else:
                 if 'array' in x["type"]:
                     try:
@@ -401,8 +404,10 @@ class Swagger2Case():
         original_ref_list = []
         return para_dict
 
-    def get_first_resp(self):
+    def get_first_resp(self,headers=None):
         session = requests.session()
+        if headers:
+            session.headers = headers
         test_cases = self.test_cases
         domain_url = self.domain_url
         for x in test_cases:
@@ -429,8 +434,8 @@ class Swagger2Case():
         conn = self.conn
         test_cases = self.test_cases
         length = len(test_cases)
-        flow_sql = '''insert into testdata_flow(`flow_code`,
-                                                `flow_name`,
+        flow_sql = '''insert into test_scenario(`scenario_code`,
+                                                `scenario_name`,
                                                 `priority`,
                                                 `account`,
                                                 `password`,
@@ -440,11 +445,11 @@ class Swagger2Case():
                                                 `update_time`,
                                                 `creater`,
                                                 `modifier`,
-                                                `tags`) values'''
+                                                `tags`) values '''
 
-        node_sql = '''insert into testdata_node(`flow_id`,
-                                                `node_code`,
-                                                `node_name`,
+        node_sql = '''insert into test_case(`scenario_id`,
+                                                `case_code`,
+                                                `case_name`,
                                                 `order_id`,
                                                 `method`,
                                                 `path`,
@@ -485,14 +490,14 @@ class Swagger2Case():
 
         flow_sql = flow_sql[:-1] + ';'
         node_sql = node_sql[:-1] + ';' 
-        node_flow_sql = f'''update testdata_node tn, testdata_flow tf
-                set tn.flow_id = tf.flow_id
-                where tn.run_env= '{env_name}' and tf.run_env = '{env_name}' and tf.flow_code = tn.node_code and tn.creater ='ywp' and tf.creater ='ywp';
+        node_flow_sql = f'''update test_case tc, test_scenario ts
+                set tc.scenario_id = ts.scenario_id
+                where tc.run_env= '{env_name}' and ts.run_env = '{env_name}' and ts.scenario_code = tc.case_code and tc.creater ='ywp' and ts.creater ='ywp';
                 '''
         sql = flow_sql + '\n' + node_sql + '\n' + node_flow_sql
         with open('init.sql','w') as file:
             file.write(sql)
-        # exec_sql(conn,flow_sql)
+        exec_sql(conn,flow_sql)
         # exec_sql(conn,node_sql)
         # exec_sql(conn,node_flow_sql)   
 
@@ -502,9 +507,9 @@ if __name__ == '__main__':
     # print(su.get_sql_dt(6))
     # print(TMP.fourelements())
     # print(TMP.full_name())
-    env_name = 'goods-domain-test'
+    env_name = 'scfp-test-v1'
     conn = 'mysql+pymysql://root:pwd@localhost:3306/common_api_test'
-    url = 'http://192.168.1.119:8118/'
+    url = 'http://10.228.64.54:24009/'
     json_file = 'swagger2case-gauge/resource/swagger.json'
     sc = Swagger2Case(env_name, conn, domain_url=url)
     # sc = Swagger2Case(env_name, conn, swagger_json_file=json_file)
